/****************************************************************************
** Meta object code from reading C++ file 'playlistbox.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../juk-26.04.1/playlistbox.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlistbox.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11PlaylistBoxE_t {};
} // unnamed namespace

template <> constexpr inline auto PlaylistBox::qt_create_metaobjectdata<qt_meta_tag_ZN11PlaylistBoxE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlaylistBox",
        "signalPlaylistDestroyed",
        "",
        "Playlist*",
        "signalMoveFocusAway",
        "startupComplete",
        "signalPlayFile",
        "FileHandle",
        "file",
        "paste",
        "clear",
        "slotFreezePlaylists",
        "slotUnfreezePlaylists",
        "slotPlaylistDataChanged",
        "slotSetHistoryPlaylistEnabled",
        "enable",
        "slotPlaylistChanged",
        "slotDoubleClicked",
        "QTreeWidgetItem*",
        "slotShowContextMenu",
        "QPoint",
        "point",
        "slotSetViewMode",
        "index",
        "slotSavePlaylists",
        "slotShowDropTarget",
        "slotPlaylistItemsDropped",
        "p",
        "slotUpdatePlayingPlaylist",
        "slotClearPlayingIndicators",
        "slotAddItem",
        "tag",
        "column",
        "slotRemoveItem",
        "slotLoadCachedPlaylists"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalPlaylistDestroyed'
        QtMocHelpers::SignalData<void(Playlist *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'signalMoveFocusAway'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startupComplete'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalPlayFile'
        QtMocHelpers::SignalData<void(const FileHandle &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFreezePlaylists'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUnfreezePlaylists'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPlaylistDataChanged'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetHistoryPlaylistEnabled'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'slotPlaylistChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDoubleClicked'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 2 },
        }}),
        // Slot 'slotShowContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'slotSetViewMode'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'slotSavePlaylists'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowDropTarget'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPlaylistItemsDropped'
        QtMocHelpers::SlotData<void(Playlist *)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 27 },
        }}),
        // Slot 'slotUpdatePlayingPlaylist'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClearPlayingIndicators'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddItem'
        QtMocHelpers::SlotData<void(const QString &, unsigned )>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 }, { QMetaType::UInt, 32 },
        }}),
        // Slot 'slotRemoveItem'
        QtMocHelpers::SlotData<void(const QString &, unsigned )>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 }, { QMetaType::UInt, 32 },
        }}),
        // Slot 'slotLoadCachedPlaylists'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlaylistBox, qt_meta_tag_ZN11PlaylistBoxE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlaylistBox::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlaylistBoxE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlaylistBoxE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PlaylistBoxE_t>.metaTypes,
    nullptr
} };

void PlaylistBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlaylistBox *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalPlaylistDestroyed((*reinterpret_cast<std::add_pointer_t<Playlist*>>(_a[1]))); break;
        case 1: _t->signalMoveFocusAway(); break;
        case 2: _t->startupComplete(); break;
        case 3: _t->signalPlayFile((*reinterpret_cast<std::add_pointer_t<FileHandle>>(_a[1]))); break;
        case 4: _t->paste(); break;
        case 5: _t->clear(); break;
        case 6: _t->slotFreezePlaylists(); break;
        case 7: _t->slotUnfreezePlaylists(); break;
        case 8: _t->slotPlaylistDataChanged(); break;
        case 9: _t->slotSetHistoryPlaylistEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->slotPlaylistChanged(); break;
        case 11: _t->slotDoubleClicked((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 12: _t->slotShowContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 13: _t->slotSetViewMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->slotSavePlaylists(); break;
        case 15: _t->slotShowDropTarget(); break;
        case 16: _t->slotPlaylistItemsDropped((*reinterpret_cast<std::add_pointer_t<Playlist*>>(_a[1]))); break;
        case 17: _t->slotUpdatePlayingPlaylist(); break;
        case 18: _t->slotClearPlayingIndicators(); break;
        case 19: _t->slotAddItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 20: _t->slotRemoveItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 21: _t->slotLoadCachedPlaylists(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlaylistBox::*)(Playlist * )>(_a, &PlaylistBox::signalPlaylistDestroyed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistBox::*)()>(_a, &PlaylistBox::signalMoveFocusAway, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistBox::*)()>(_a, &PlaylistBox::startupComplete, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlaylistBox::*)(const FileHandle & )>(_a, &PlaylistBox::signalPlayFile, 3))
            return;
    }
}

const QMetaObject *PlaylistBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlaylistBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlaylistBoxE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PlaylistCollection"))
        return static_cast< PlaylistCollection*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int PlaylistBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void PlaylistBox::signalPlaylistDestroyed(Playlist * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PlaylistBox::signalMoveFocusAway()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlaylistBox::startupComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PlaylistBox::signalPlayFile(const FileHandle & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN11PlaylistBox4ItemE_t {};
} // unnamed namespace

template <> constexpr inline auto PlaylistBox::Item::qt_create_metaobjectdata<qt_meta_tag_ZN11PlaylistBox4ItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlaylistBox::Item",
        "slotSetName",
        "",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotSetName'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Item, qt_meta_tag_ZN11PlaylistBox4ItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlaylistBox::Item::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlaylistBox4ItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlaylistBox4ItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PlaylistBox4ItemE_t>.metaTypes,
    nullptr
} };

void PlaylistBox::Item::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Item *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotSetName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *PlaylistBox::Item::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlaylistBox::Item::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PlaylistBox4ItemE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QTreeWidgetItem"))
        return static_cast< QTreeWidgetItem*>(this);
    return QObject::qt_metacast(_clname);
}

int PlaylistBox::Item::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
