/****************************************************************************
** Meta object code from reading C++ file 'dbuscollectionproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../juk-26.04.1/dbuscollectionproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbuscollectionproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19DBusCollectionProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusCollectionProxy::qt_create_metaobjectdata<qt_meta_tag_ZN19DBusCollectionProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusCollectionProxy",
        "D-Bus Interface",
        "org.kde.juk.collection",
        "openFile",
        "",
        "file",
        "files",
        "playlist",
        "visiblePlaylist",
        "playingPlaylist",
        "playlists",
        "playlistTracks",
        "trackProperty",
        "property",
        "createPlaylist",
        "name",
        "setPlaylist",
        "remove",
        "removeTrack",
        "trackCover",
        "track"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'openFile'
        QtMocHelpers::SlotData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void(const QStringList &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 6 },
        }}),
        // Slot 'visiblePlaylist'
        QtMocHelpers::SlotData<QString()>(8, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'playingPlaylist'
        QtMocHelpers::SlotData<QString()>(9, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'playlists'
        QtMocHelpers::SlotData<QStringList()>(10, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'playlistTracks'
        QtMocHelpers::SlotData<QStringList(const QString &)>(11, 4, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'trackProperty'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(12, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'createPlaylist'
        QtMocHelpers::SlotData<void(const QString &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'setPlaylist'
        QtMocHelpers::SlotData<void(const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeTrack'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QStringList, 6 },
        }}),
        // Slot 'trackCover'
        QtMocHelpers::SlotData<QString(const QString &)>(19, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DBusCollectionProxy, qt_meta_tag_ZN19DBusCollectionProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DBusCollectionProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DBusCollectionProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DBusCollectionProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19DBusCollectionProxyE_t>.metaTypes,
    nullptr
} };

void DBusCollectionProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusCollectionProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->openFile((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 4: { QString _r = _t->visiblePlaylist();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->playingPlaylist();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QStringList _r = _t->playlists();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->playlistTracks((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->trackProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->createPlaylist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->setPlaylist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->remove(); break;
        case 12: _t->removeTrack((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 13: { QString _r = _t->trackCover((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *DBusCollectionProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusCollectionProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19DBusCollectionProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusCollectionProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
