/****************************************************************************
** Meta object code from reading C++ file 'playeradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "playeradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playeradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13PlayerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto PlayerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN13PlayerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlayerAdaptor",
        "D-Bus Interface",
        "org.kde.juk.player",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.juk.player\">\n    <method name=\"play"
        "ing\">\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n"
        "    <method name=\"paused\">\n      <arg direction=\"out\" type=\""
        "b\"/>\n    </method>\n    <method name=\"volume\">\n      <arg dir"
        "ection=\"out\" type=\"d\"/>\n    </method>\n    <method name=\"sta"
        "tus\">\n      <arg direction=\"out\" type=\"i\"/>\n    </method>\n"
        "    <method name=\"trackProperties\">\n      <arg direction=\"out\""
        " type=\"as\"/>\n    </method>\n    <method name=\"trackProperty\">"
        "\n      <arg direction=\"out\" type=\"s\"/>\n      <arg direction="
        "\"in\" type=\"s\" name=\"property\"/>\n    </method>\n    <method "
        "name=\"play\"/>\n    <method name=\"play\">\n      <arg direction="
        "\"in\" type=\"s\" name=\"file\"/>\n    </method>\n    <method name"
        "=\"pause\"/>\n    <method name=\"stop\"/>\n    <method name=\"play"
        "Pause\"/>\n    <method name=\"back\"/>\n    <method name=\"forward"
        "\"/>\n    <method name=\"seekBack\"/>\n    <method name=\"seekForw"
        "ard\"/>\n    <method name=\"volumeUp\"/>\n    <method name=\"volum"
        "eDown\"/>\n    <method name=\"mute\"/>\n    <method name=\"setVolu"
        "me\">\n      <arg direction=\"in\" type=\"d\" name=\"volume\"/>\n "
        "   </method>\n    <method name=\"playingString\">\n      <arg dire"
        "ction=\"out\" type=\"s\"/>\n    </method>\n    <method name=\"curr"
        "entTime\">\n      <arg direction=\"out\" type=\"i\"/>\n    </metho"
        "d>\n    <method name=\"totalTime\">\n      <arg direction=\"out\" "
        "type=\"i\"/>\n    </method>\n    <method name=\"currentTimeMSecs\""
        ">\n      <arg direction=\"out\" type=\"i\"/>\n    </method>\n    <"
        "method name=\"totalTimeMSecs\">\n      <arg direction=\"out\" type"
        "=\"i\"/>\n    </method>\n    <method name=\"randomPlayMode\">\n   "
        "   <arg direction=\"out\" type=\"s\"/>\n    </method>\n    <method"
        " name=\"setRandomPlayMode\">\n      <arg direction=\"in\" type=\"s"
        "\" name=\"randomMode\"/>\n    </method>\n  </interface>\n",
        "back",
        "",
        "currentTime",
        "currentTimeMSecs",
        "forward",
        "mute",
        "pause",
        "paused",
        "play",
        "file",
        "playPause",
        "playing",
        "playingString",
        "randomPlayMode",
        "seekBack",
        "seekForward",
        "setRandomPlayMode",
        "randomMode",
        "setVolume",
        "volume",
        "status",
        "stop",
        "totalTime",
        "totalTimeMSecs",
        "trackProperties",
        "trackProperty",
        "property",
        "volumeDown",
        "volumeUp"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'back'
        QtMocHelpers::SlotData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'currentTime'
        QtMocHelpers::SlotData<int()>(7, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'currentTimeMSecs'
        QtMocHelpers::SlotData<int()>(8, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'forward'
        QtMocHelpers::SlotData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mute'
        QtMocHelpers::SlotData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paused'
        QtMocHelpers::SlotData<bool()>(12, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'play'
        QtMocHelpers::SlotData<void(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playPause'
        QtMocHelpers::SlotData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playing'
        QtMocHelpers::SlotData<bool()>(16, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'playingString'
        QtMocHelpers::SlotData<QString()>(17, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'randomPlayMode'
        QtMocHelpers::SlotData<QString()>(18, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'seekBack'
        QtMocHelpers::SlotData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekForward'
        QtMocHelpers::SlotData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setRandomPlayMode'
        QtMocHelpers::SlotData<void(const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(double)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 24 },
        }}),
        // Slot 'status'
        QtMocHelpers::SlotData<int()>(25, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'totalTime'
        QtMocHelpers::SlotData<int()>(27, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'totalTimeMSecs'
        QtMocHelpers::SlotData<int()>(28, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'trackProperties'
        QtMocHelpers::SlotData<QStringList()>(29, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'trackProperty'
        QtMocHelpers::SlotData<QString(const QString &)>(30, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'volume'
        QtMocHelpers::SlotData<double()>(24, 6, QMC::AccessPublic, QMetaType::Double),
        // Slot 'volumeDown'
        QtMocHelpers::SlotData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'volumeUp'
        QtMocHelpers::SlotData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PlayerAdaptor, qt_meta_tag_ZN13PlayerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PlayerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PlayerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PlayerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13PlayerAdaptorE_t>.metaTypes,
    nullptr
} };

void PlayerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlayerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->back(); break;
        case 1: { int _r = _t->currentTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 2: { int _r = _t->currentTimeMSecs();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->forward(); break;
        case 4: _t->mute(); break;
        case 5: _t->pause(); break;
        case 6: { bool _r = _t->paused();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->play((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->play(); break;
        case 9: _t->playPause(); break;
        case 10: { bool _r = _t->playing();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->playingString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->randomPlayMode();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->seekBack(); break;
        case 14: _t->seekForward(); break;
        case 15: _t->setRandomPlayMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->setVolume((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: { int _r = _t->status();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->stop(); break;
        case 19: { int _r = _t->totalTime();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 20: { int _r = _t->totalTimeMSecs();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 21: { QStringList _r = _t->trackProperties();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 22: { QString _r = _t->trackProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 23: { double _r = _t->volume();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->volumeDown(); break;
        case 25: _t->volumeUp(); break;
        default: ;
        }
    }
}

const QMetaObject *PlayerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlayerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PlayerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int PlayerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}
QT_WARNING_POP
