/****************************************************************************
** Meta object code from reading C++ file 'playermanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../juk-26.04.1/playermanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13PlayerManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto PlayerManager::qt_create_metaobjectdata<qt_meta_tag_ZN13PlayerManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlayerManager",
        "tick",
        "",
        "totalTimeChanged",
        "mutedChanged",
        "muted",
        "volumeChanged",
        "volume",
        "seeked",
        "newPos",
        "seekableChanged",
        "signalPlay",
        "signalPause",
        "signalStop",
        "signalItemChanged",
        "FileHandle",
        "file",
        "play",
        "pause",
        "stop",
        "seek",
        "seekTime",
        "seekForward",
        "seekBack",
        "playPause",
        "forward",
        "back",
        "setVolume",
        "volumeUp",
        "volumeDown",
        "setMuted",
        "m",
        "mute",
        "trackHasChanged",
        "QUrl",
        "newSource",
        "setRandomPlayMode",
        "randomMode",
        "slotFinished",
        "slotLength",
        "slotTick",
        "slotStateChanged",
        "QMediaPlayer::PlaybackState",
        "slotSeekableChanged",
        "slotMutedChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tick'
        QtMocHelpers::SignalData<void(qint64)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 2 },
        }}),
        // Signal 'totalTimeChanged'
        QtMocHelpers::SignalData<void(qint64)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 2 },
        }}),
        // Signal 'mutedChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void(float)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 7 },
        }}),
        // Signal 'seeked'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'seekableChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'signalPlay'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalPause'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalStop'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalItemChanged'
        QtMocHelpers::SignalData<void(const FileHandle &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void(const FileHandle &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seek'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'seekForward'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekBack'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playPause'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forward'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'back'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(qreal)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'volumeUp'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'volumeDown'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMuted'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'mute'
        QtMocHelpers::SlotData<bool()>(32, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'trackHasChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'setRandomPlayMode'
        QtMocHelpers::SlotData<void(const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'slotFinished'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLength'
        QtMocHelpers::SlotData<void(qint64)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 2 },
        }}),
        // Slot 'slotTick'
        QtMocHelpers::SlotData<void(qint64)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 2 },
        }}),
        // Slot 'slotStateChanged'
        QtMocHelpers::SlotData<void(QMediaPlayer::PlaybackState)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 2 },
        }}),
        // Slot 'slotSeekableChanged'
        QtMocHelpers::SlotData<void(bool)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotMutedChanged'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlayerManager, qt_meta_tag_ZN13PlayerManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlayerManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PlayerManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PlayerManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13PlayerManagerE_t>.metaTypes,
    nullptr
} };

void PlayerManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlayerManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tick((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 1: _t->totalTimeChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 2: _t->mutedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->volumeChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 4: _t->seeked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->seekableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->signalPlay(); break;
        case 7: _t->signalPause(); break;
        case 8: _t->signalStop(); break;
        case 9: _t->signalItemChanged((*reinterpret_cast<std::add_pointer_t<FileHandle>>(_a[1]))); break;
        case 10: _t->play((*reinterpret_cast<std::add_pointer_t<FileHandle>>(_a[1]))); break;
        case 11: _t->play((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->play(); break;
        case 13: _t->pause(); break;
        case 14: _t->stop(); break;
        case 15: _t->seek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->seekForward(); break;
        case 17: _t->seekBack(); break;
        case 18: _t->playPause(); break;
        case 19: _t->forward(); break;
        case 20: _t->back(); break;
        case 21: _t->setVolume((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 22: _t->volumeUp(); break;
        case 23: _t->volumeDown(); break;
        case 24: _t->setMuted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: { bool _r = _t->mute();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->trackHasChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 27: _t->setRandomPlayMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->slotFinished(); break;
        case 29: _t->slotLength((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 30: _t->slotTick((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 31: _t->slotStateChanged((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::PlaybackState>>(_a[1]))); break;
        case 32: _t->slotSeekableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->slotMutedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FileHandle >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FileHandle >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlayerManager::*)(qint64 )>(_a, &PlayerManager::tick, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerManager::*)(qint64 )>(_a, &PlayerManager::totalTimeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerManager::*)(bool )>(_a, &PlayerManager::mutedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerManager::*)(float )>(_a, &PlayerManager::volumeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerManager::*)(int )>(_a, &PlayerManager::seeked, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerManager::*)(bool )>(_a, &PlayerManager::seekableChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerManager::*)()>(_a, &PlayerManager::signalPlay, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerManager::*)()>(_a, &PlayerManager::signalPause, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerManager::*)()>(_a, &PlayerManager::signalStop, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlayerManager::*)(const FileHandle & )>(_a, &PlayerManager::signalItemChanged, 9))
            return;
    }
}

const QMetaObject *PlayerManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlayerManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PlayerManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PlayerManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void PlayerManager::tick(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PlayerManager::totalTimeChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PlayerManager::mutedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PlayerManager::volumeChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PlayerManager::seeked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PlayerManager::seekableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void PlayerManager::signalPlay()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PlayerManager::signalPause()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PlayerManager::signalStop()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PlayerManager::signalItemChanged(const FileHandle & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
