/****************************************************************************
** Meta object code from reading C++ file 'collectionadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "collectionadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'collectionadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17CollectionAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto CollectionAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN17CollectionAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CollectionAdaptor",
        "D-Bus Interface",
        "org.kde.juk.collection",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.juk.collection\">\n    <method name=\""
        "openFile\">\n      <arg direction=\"in\" type=\"s\" name=\"file\"/"
        ">\n    </method>\n    <method name=\"openFile\">\n      <arg direc"
        "tion=\"in\" type=\"as\" name=\"files\"/>\n    </method>\n    <meth"
        "od name=\"openFile\">\n      <arg direction=\"in\" type=\"s\" name"
        "=\"playlist\"/>\n      <arg direction=\"in\" type=\"s\" name=\"fil"
        "e\"/>\n    </method>\n    <method name=\"openFile\">\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"playlist\"/>\n      <arg directi"
        "on=\"in\" type=\"as\" name=\"files\"/>\n    </method>\n    <method"
        " name=\"visiblePlaylist\">\n      <arg direction=\"out\" type=\"s\""
        "/>\n    </method>\n    <method name=\"playingPlaylist\">\n      <a"
        "rg direction=\"out\" type=\"s\"/>\n    </method>\n    <method name"
        "=\"playlists\">\n      <arg direction=\"out\" type=\"as\"/>\n    <"
        "/method>\n    <method name=\"playlistTracks\">\n      <arg directi"
        "on=\"out\" type=\"as\"/>\n      <arg direction=\"in\" type=\"s\" n"
        "ame=\"playlist\"/>\n    </method>\n    <method name=\"trackPropert"
        "y\">\n      <arg direction=\"out\" type=\"s\"/>\n      <arg direct"
        "ion=\"in\" type=\"s\" name=\"file\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"property\"/>\n    </method>\n    <method name=\""
        "createPlaylist\">\n      <arg direction=\"in\" type=\"s\" name=\"n"
        "ame\"/>\n    </method>\n    <method name=\"setPlaylist\">\n      <"
        "arg direction=\"in\" type=\"s\" name=\"name\"/>\n    </method>\n  "
        "  <method name=\"remove\"/>\n    <method name=\"removeTrack\">\n  "
        "    <arg direction=\"in\" type=\"s\" name=\"playlist\"/>\n      <a"
        "rg direction=\"in\" type=\"as\" name=\"files\"/>\n    </method>\n "
        "   <method name=\"trackCover\">\n      <arg direction=\"out\" type"
        "=\"s\"/>\n      <arg direction=\"in\" type=\"s\" name=\"track\"/>\n"
        "    </method>\n  </interface>\n",
        "createPlaylist",
        "",
        "name",
        "openFile",
        "playlist",
        "files",
        "file",
        "playingPlaylist",
        "playlistTracks",
        "playlists",
        "remove",
        "removeTrack",
        "setPlaylist",
        "trackCover",
        "track",
        "trackProperty",
        "property",
        "visiblePlaylist"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createPlaylist'
        QtMocHelpers::SlotData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QStringList, 10 },
        }}),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void(const QStringList &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 10 },
        }}),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'playingPlaylist'
        QtMocHelpers::SlotData<QString()>(12, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'playlistTracks'
        QtMocHelpers::SlotData<QStringList(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'playlists'
        QtMocHelpers::SlotData<QStringList()>(14, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'remove'
        QtMocHelpers::SlotData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeTrack'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QStringList, 10 },
        }}),
        // Slot 'setPlaylist'
        QtMocHelpers::SlotData<void(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'trackCover'
        QtMocHelpers::SlotData<QString(const QString &)>(18, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'trackProperty'
        QtMocHelpers::SlotData<QString(const QString &, const QString &)>(20, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'visiblePlaylist'
        QtMocHelpers::SlotData<QString()>(22, 6, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CollectionAdaptor, qt_meta_tag_ZN17CollectionAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CollectionAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CollectionAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CollectionAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CollectionAdaptorE_t>.metaTypes,
    nullptr
} };

void CollectionAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CollectionAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->createPlaylist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 2: _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->openFile((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { QString _r = _t->playingPlaylist();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QStringList _r = _t->playlistTracks((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->playlists();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->remove(); break;
        case 9: _t->removeTrack((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 10: _t->setPlaylist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: { QString _r = _t->trackCover((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->trackProperty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->visiblePlaylist();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *CollectionAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CollectionAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CollectionAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int CollectionAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
