/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.juk.collection.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef COLLECTIONADAPTOR_H
#define COLLECTIONADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "dbuscollectionproxy.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.juk.collection
 */
class CollectionAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.juk.collection")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.juk.collection\">\n"
"    <method name=\"openFile\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"    </method>\n"
"    <method name=\"openFile\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"    </method>\n"
"    <method name=\"openFile\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"playlist\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"    </method>\n"
"    <method name=\"openFile\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"playlist\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"    </method>\n"
"    <method name=\"visiblePlaylist\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"playingPlaylist\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"playlists\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"playlistTracks\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"playlist\"/>\n"
"    </method>\n"
"    <method name=\"trackProperty\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"property\"/>\n"
"    </method>\n"
"    <method name=\"createPlaylist\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"setPlaylist\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"remove\"/>\n"
"    <method name=\"removeTrack\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"playlist\"/>\n"
"      <arg direction=\"in\" type=\"as\" name=\"files\"/>\n"
"    </method>\n"
"    <method name=\"trackCover\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"track\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    CollectionAdaptor(DBusCollectionProxy *parent);
    ~CollectionAdaptor() override;

    inline DBusCollectionProxy *parent() const
    { return static_cast<DBusCollectionProxy *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void createPlaylist(const QString &name);
    void openFile(const QString &playlist, const QStringList &files);
    void openFile(const QString &playlist, const QString &file);
    void openFile(const QStringList &files);
    void openFile(const QString &file);
    QString playingPlaylist();
    QStringList playlistTracks(const QString &playlist);
    QStringList playlists();
    void remove();
    void removeTrack(const QString &playlist, const QStringList &files);
    void setPlaylist(const QString &name);
    QString trackCover(const QString &track);
    QString trackProperty(const QString &file, const QString &property);
    QString visiblePlaylist();
Q_SIGNALS: // SIGNALS
};

#endif
