/********************************************************************************
** Form generated from reading UI file 'tageditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TAGEDITOR_H
#define UI_TAGEDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_TagEditor
{
public:
    QHBoxLayout *horizontalLayout;
    QGridLayout *tagEditorLayout;
    QLabel *fileNameLabel;
    QLabel *trackLabel;
    QLabel *artistNameLabel;
    QLabel *albumNameLabel;
    QLabel *genreLabel;
    KLineEdit *fileNameBox;
    QLabel *yearLabel;
    KLineEdit *lengthBox;
    KLineEdit *bitrateBox;
    QLabel *lengthLabel;
    QLabel *bitrateLabel;
    QLabel *commentLabel;
    KTextEdit *commentBox;
    QSpacerItem *verticalSpacer;
    KComboBox *albumNameBox;
    KComboBox *genreBox;
    KComboBox *artistNameBox;
    QSpinBox *trackSpin;
    QSpinBox *yearSpin;
    QFrame *line;
    QLabel *trackNameLabel;
    QCheckBox *artistNameEnable;
    KLineEdit *trackNameBox;
    QCheckBox *trackNameEnable;
    QCheckBox *albumNameEnable;
    QCheckBox *genreEnable;
    QCheckBox *trackEnable;
    QCheckBox *yearEnable;
    QCheckBox *commentEnable;
    QFrame *line_2;

    void setupUi(QWidget *TagEditor)
    {
        if (TagEditor->objectName().isEmpty())
            TagEditor->setObjectName("TagEditor");
        TagEditor->resize(885, 416);
        horizontalLayout = new QHBoxLayout(TagEditor);
        horizontalLayout->setObjectName("horizontalLayout");
        tagEditorLayout = new QGridLayout();
        tagEditorLayout->setObjectName("tagEditorLayout");
        fileNameLabel = new QLabel(TagEditor);
        fileNameLabel->setObjectName("fileNameLabel");

        tagEditorLayout->addWidget(fileNameLabel, 0, 3, 1, 7);

        trackLabel = new QLabel(TagEditor);
        trackLabel->setObjectName("trackLabel");

        tagEditorLayout->addWidget(trackLabel, 2, 3, 1, 1);

        artistNameLabel = new QLabel(TagEditor);
        artistNameLabel->setObjectName("artistNameLabel");

        tagEditorLayout->addWidget(artistNameLabel, 0, 0, 1, 1);

        albumNameLabel = new QLabel(TagEditor);
        albumNameLabel->setObjectName("albumNameLabel");

        tagEditorLayout->addWidget(albumNameLabel, 4, 0, 1, 1);

        genreLabel = new QLabel(TagEditor);
        genreLabel->setObjectName("genreLabel");

        tagEditorLayout->addWidget(genreLabel, 6, 0, 1, 1);

        fileNameBox = new KLineEdit(TagEditor);
        fileNameBox->setObjectName("fileNameBox");

        tagEditorLayout->addWidget(fileNameBox, 1, 3, 1, 7);

        yearLabel = new QLabel(TagEditor);
        yearLabel->setObjectName("yearLabel");

        tagEditorLayout->addWidget(yearLabel, 2, 7, 1, 1);

        lengthBox = new KLineEdit(TagEditor);
        lengthBox->setObjectName("lengthBox");
        lengthBox->setReadOnly(true);

        tagEditorLayout->addWidget(lengthBox, 3, 4, 1, 1);

        bitrateBox = new KLineEdit(TagEditor);
        bitrateBox->setObjectName("bitrateBox");
        bitrateBox->setReadOnly(true);

        tagEditorLayout->addWidget(bitrateBox, 3, 8, 1, 1);

        lengthLabel = new QLabel(TagEditor);
        lengthLabel->setObjectName("lengthLabel");

        tagEditorLayout->addWidget(lengthLabel, 3, 3, 1, 1);

        bitrateLabel = new QLabel(TagEditor);
        bitrateLabel->setObjectName("bitrateLabel");

        tagEditorLayout->addWidget(bitrateLabel, 3, 7, 1, 1);

        commentLabel = new QLabel(TagEditor);
        commentLabel->setObjectName("commentLabel");

        tagEditorLayout->addWidget(commentLabel, 4, 3, 1, 2);

        commentBox = new KTextEdit(TagEditor);
        commentBox->setObjectName("commentBox");

        tagEditorLayout->addWidget(commentBox, 5, 3, 4, 7);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        tagEditorLayout->addItem(verticalSpacer, 8, 0, 1, 1);

        albumNameBox = new KComboBox(TagEditor);
        albumNameBox->setObjectName("albumNameBox");
        albumNameBox->setEditable(true);

        tagEditorLayout->addWidget(albumNameBox, 5, 0, 1, 2);

        genreBox = new KComboBox(TagEditor);
        genreBox->setObjectName("genreBox");
        genreBox->setEditable(true);

        tagEditorLayout->addWidget(genreBox, 7, 0, 1, 2);

        artistNameBox = new KComboBox(TagEditor);
        artistNameBox->setObjectName("artistNameBox");
        artistNameBox->setEditable(true);

        tagEditorLayout->addWidget(artistNameBox, 1, 0, 1, 2);

        trackSpin = new QSpinBox(TagEditor);
        trackSpin->setObjectName("trackSpin");
        trackSpin->setMaximum(999);

        tagEditorLayout->addWidget(trackSpin, 2, 4, 1, 1);

        yearSpin = new QSpinBox(TagEditor);
        yearSpin->setObjectName("yearSpin");
        yearSpin->setMaximum(9999);

        tagEditorLayout->addWidget(yearSpin, 2, 8, 1, 1);

        line = new QFrame(TagEditor);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::VLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        tagEditorLayout->addWidget(line, 0, 2, 8, 1);

        trackNameLabel = new QLabel(TagEditor);
        trackNameLabel->setObjectName("trackNameLabel");

        tagEditorLayout->addWidget(trackNameLabel, 2, 0, 1, 1);

        artistNameEnable = new QCheckBox(TagEditor);
        artistNameEnable->setObjectName("artistNameEnable");
        artistNameEnable->setProperty("associatedObjectName", QVariant(QByteArray("artistNameBox")));

        tagEditorLayout->addWidget(artistNameEnable, 0, 1, 1, 1);

        trackNameBox = new KLineEdit(TagEditor);
        trackNameBox->setObjectName("trackNameBox");

        tagEditorLayout->addWidget(trackNameBox, 3, 0, 1, 2);

        trackNameEnable = new QCheckBox(TagEditor);
        trackNameEnable->setObjectName("trackNameEnable");
        trackNameEnable->setProperty("associatedObjectName", QVariant(QByteArray("trackNameBox")));

        tagEditorLayout->addWidget(trackNameEnable, 2, 1, 1, 1);

        albumNameEnable = new QCheckBox(TagEditor);
        albumNameEnable->setObjectName("albumNameEnable");
        albumNameEnable->setProperty("associatedObjectName", QVariant(QByteArray("albumNameBox")));

        tagEditorLayout->addWidget(albumNameEnable, 4, 1, 1, 1);

        genreEnable = new QCheckBox(TagEditor);
        genreEnable->setObjectName("genreEnable");
        genreEnable->setProperty("associatedObjectName", QVariant(QByteArray("genreBox")));

        tagEditorLayout->addWidget(genreEnable, 6, 1, 1, 1);

        trackEnable = new QCheckBox(TagEditor);
        trackEnable->setObjectName("trackEnable");
        trackEnable->setProperty("associatedObjectName", QVariant(QByteArray("trackSpin")));

        tagEditorLayout->addWidget(trackEnable, 2, 5, 1, 1);

        yearEnable = new QCheckBox(TagEditor);
        yearEnable->setObjectName("yearEnable");
        yearEnable->setProperty("associatedObjectName", QVariant(QByteArray("yearSpin")));

        tagEditorLayout->addWidget(yearEnable, 2, 9, 1, 1);

        commentEnable = new QCheckBox(TagEditor);
        commentEnable->setObjectName("commentEnable");
        commentEnable->setProperty("associatedObjectName", QVariant(QByteArray("commentBox")));

        tagEditorLayout->addWidget(commentEnable, 4, 5, 1, 5);

        line_2 = new QFrame(TagEditor);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::VLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        tagEditorLayout->addWidget(line_2, 2, 6, 2, 1);


        horizontalLayout->addLayout(tagEditorLayout);

#if QT_CONFIG(shortcut)
        fileNameLabel->setBuddy(fileNameBox);
        trackLabel->setBuddy(trackSpin);
        artistNameLabel->setBuddy(artistNameBox);
        albumNameLabel->setBuddy(albumNameBox);
        genreLabel->setBuddy(genreBox);
        yearLabel->setBuddy(yearSpin);
        lengthLabel->setBuddy(lengthBox);
        bitrateLabel->setBuddy(bitrateBox);
        commentLabel->setBuddy(commentBox);
        trackNameLabel->setBuddy(trackNameBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(artistNameEnable, artistNameBox);
        QWidget::setTabOrder(artistNameBox, trackNameEnable);
        QWidget::setTabOrder(trackNameEnable, trackNameBox);
        QWidget::setTabOrder(trackNameBox, albumNameEnable);
        QWidget::setTabOrder(albumNameEnable, albumNameBox);
        QWidget::setTabOrder(albumNameBox, genreEnable);
        QWidget::setTabOrder(genreEnable, genreBox);
        QWidget::setTabOrder(genreBox, fileNameBox);
        QWidget::setTabOrder(fileNameBox, trackEnable);
        QWidget::setTabOrder(trackEnable, trackSpin);
        QWidget::setTabOrder(trackSpin, lengthBox);
        QWidget::setTabOrder(lengthBox, yearEnable);
        QWidget::setTabOrder(yearEnable, yearSpin);
        QWidget::setTabOrder(yearSpin, bitrateBox);
        QWidget::setTabOrder(bitrateBox, commentEnable);
        QWidget::setTabOrder(commentEnable, commentBox);

        retranslateUi(TagEditor);
        QObject::connect(artistNameEnable, SIGNAL(toggled(bool)), artistNameBox, SLOT(setEnabled(bool)));
        QObject::connect(trackNameEnable, SIGNAL(toggled(bool)), trackNameBox, SLOT(setEnabled(bool)));
        QObject::connect(albumNameEnable, SIGNAL(toggled(bool)), albumNameBox, SLOT(setEnabled(bool)));
        QObject::connect(genreEnable, SIGNAL(toggled(bool)), genreBox, SLOT(setEnabled(bool)));
        QObject::connect(trackEnable, &QCheckBox::toggled, trackSpin, &QSpinBox::setEnabled);
        QObject::connect(commentEnable, SIGNAL(toggled(bool)), commentBox, SLOT(setEnabled(bool)));
        QObject::connect(yearEnable, &QCheckBox::toggled, yearSpin, &QSpinBox::setEnabled);
        QObject::connect(artistNameBox, SIGNAL(editTextChanged(QString)), TagEditor, SLOT(slotDataChanged()));
        QObject::connect(trackNameBox, SIGNAL(textChanged(QString)), TagEditor, SLOT(slotDataChanged()));
        QObject::connect(albumNameBox, SIGNAL(editTextChanged(QString)), TagEditor, SLOT(slotDataChanged()));
        QObject::connect(genreBox, SIGNAL(editTextChanged(QString)), TagEditor, SLOT(slotDataChanged()));
        QObject::connect(commentBox, SIGNAL(textChanged()), TagEditor, SLOT(slotDataChanged()));
        QObject::connect(trackSpin, SIGNAL(valueChanged(int)), TagEditor, SLOT(slotDataChanged()));
        QObject::connect(yearSpin, SIGNAL(valueChanged(int)), TagEditor, SLOT(slotDataChanged()));

        QMetaObject::connectSlotsByName(TagEditor);
    } // setupUi

    void retranslateUi(QWidget *TagEditor)
    {
        fileNameLabel->setText(tr2i18n("F&ile name:", nullptr));
        trackLabel->setText(tr2i18n("T&rack:", nullptr));
        artistNameLabel->setText(tr2i18n("&Artist name:", nullptr));
        albumNameLabel->setText(tr2i18n("Album &name:", nullptr));
        genreLabel->setText(tr2i18n("&Genre:", nullptr));
        yearLabel->setText(tr2i18n("&Year:", nullptr));
        lengthLabel->setText(tr2i18n("&Length:", nullptr));
        bitrateLabel->setText(tr2i18n("&Bitrate:", nullptr));
        commentLabel->setText(tr2i18n("&Comment:", nullptr));
        trackNameLabel->setText(tr2i18n("Trac&k name:", nullptr));
        artistNameEnable->setText(tr2i18n("Enable", nullptr));
        trackNameEnable->setText(tr2i18n("Enable", nullptr));
        albumNameEnable->setText(tr2i18n("Enable", nullptr));
        genreEnable->setText(tr2i18n("Enable", nullptr));
        trackEnable->setText(tr2i18n("Enable", nullptr));
        yearEnable->setText(tr2i18n("Enable", nullptr));
        commentEnable->setText(tr2i18n("Enable", nullptr));
        (void)TagEditor;
    } // retranslateUi

};

namespace Ui {
    class TagEditor: public Ui_TagEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TAGEDITOR_H

