/****************************************************************************
** Meta object code from reading C++ file 'playlist.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../juk-26.04.1/playlist.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlist.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8PlaylistE_t {};
} // unnamed namespace

template <> constexpr inline auto Playlist::qt_create_metaobjectdata<qt_meta_tag_ZN8PlaylistE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Playlist",
        "signalNameChanged",
        "",
        "name",
        "signalAboutToRemove",
        "PlaylistItem*",
        "item",
        "signalEnableDirWatch",
        "enable",
        "signalPlaylistItemsDropped",
        "Playlist*",
        "p",
        "signalMoveFocusAway",
        "slotRemoveSelectedItems",
        "cut",
        "copy",
        "paste",
        "clear",
        "slotRefresh",
        "slotOpenItemDir",
        "slotGuessTagInfo",
        "TagGuesser::Type",
        "type",
        "slotRenameFile",
        "slotBeginPlayback",
        "slotReload",
        "refillRandomList",
        "slotWeightDirty",
        "column",
        "slotShowPlaying",
        "slotColumnResizeModeChanged",
        "slotPopulateBackMenu",
        "slotPlayFromBackMenu",
        "QAction*",
        "slotInitialize",
        "numColumnsToReserve",
        "slotUpdateColumnWidths",
        "slotAddToUpcoming",
        "slotShowRMBMenu",
        "QPoint",
        "point",
        "slotInlineEditDone",
        "QTreeWidgetItem*",
        "slotColumnOrderChanged",
        "from",
        "to",
        "slotToggleColumnVisible",
        "action",
        "slotCreateGroup",
        "columnResized",
        "oldSize",
        "newSize",
        "slotPlayCurrent",
        "slotUpdateTime"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'signalAboutToRemove'
        QtMocHelpers::SignalData<void(PlaylistItem *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'signalEnableDirWatch'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'signalPlaylistItemsDropped'
        QtMocHelpers::SignalData<void(Playlist *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'signalMoveFocusAway'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveSelectedItems'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cut'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copy'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'paste'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRefresh'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOpenItemDir'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGuessTagInfo'
        QtMocHelpers::SlotData<void(TagGuesser::Type)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'slotRenameFile'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBeginPlayback'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotReload'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refillRandomList'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotWeightDirty'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'slotWeightDirty'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotShowPlaying'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotColumnResizeModeChanged'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPopulateBackMenu'
        QtMocHelpers::SlotData<void() const>(31, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotPlayFromBackMenu'
        QtMocHelpers::SlotData<void(QAction *)>(32, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 33, 2 },
        }}),
        // Slot 'slotInitialize'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
        // Slot 'slotUpdateColumnWidths'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddToUpcoming'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowRMBMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'slotInlineEditDone'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 2 }, { QMetaType::Int, 28 },
        }}),
        // Slot 'slotColumnOrderChanged'
        QtMocHelpers::SlotData<void(int, int, int)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 44 }, { QMetaType::Int, 45 },
        }}),
        // Slot 'slotToggleColumnVisible'
        QtMocHelpers::SlotData<void(QAction *)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 47 },
        }}),
        // Slot 'slotCreateGroup'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'columnResized'
        QtMocHelpers::SlotData<void(int, int, int)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { QMetaType::Int, 50 }, { QMetaType::Int, 51 },
        }}),
        // Slot 'slotPlayCurrent'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateTime'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Playlist, qt_meta_tag_ZN8PlaylistE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Playlist::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8PlaylistE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8PlaylistE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8PlaylistE_t>.metaTypes,
    nullptr
} };

void Playlist::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Playlist *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->signalAboutToRemove((*reinterpret_cast<std::add_pointer_t<PlaylistItem*>>(_a[1]))); break;
        case 2: _t->signalEnableDirWatch((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->signalPlaylistItemsDropped((*reinterpret_cast<std::add_pointer_t<Playlist*>>(_a[1]))); break;
        case 4: _t->signalMoveFocusAway(); break;
        case 5: _t->slotRemoveSelectedItems(); break;
        case 6: _t->cut(); break;
        case 7: _t->copy(); break;
        case 8: _t->paste(); break;
        case 9: _t->clear(); break;
        case 10: _t->slotRefresh(); break;
        case 11: _t->slotOpenItemDir(); break;
        case 12: _t->slotGuessTagInfo((*reinterpret_cast<std::add_pointer_t<TagGuesser::Type>>(_a[1]))); break;
        case 13: _t->slotRenameFile(); break;
        case 14: _t->slotBeginPlayback(); break;
        case 15: _t->slotReload(); break;
        case 16: _t->refillRandomList(); break;
        case 17: _t->slotWeightDirty((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->slotWeightDirty(); break;
        case 19: _t->slotShowPlaying(); break;
        case 20: _t->slotColumnResizeModeChanged(); break;
        case 21: _t->slotPopulateBackMenu(); break;
        case 22: _t->slotPlayFromBackMenu((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 23: _t->slotInitialize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->slotUpdateColumnWidths(); break;
        case 25: _t->slotAddToUpcoming(); break;
        case 26: _t->slotShowRMBMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 27: _t->slotInlineEditDone((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 28: _t->slotColumnOrderChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 29: _t->slotToggleColumnVisible((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 30: _t->slotCreateGroup(); break;
        case 31: _t->columnResized((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 32: _t->slotPlayCurrent(); break;
        case 33: _t->slotUpdateTime(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Playlist* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Playlist::*)(const QString & )>(_a, &Playlist::signalNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Playlist::*)(PlaylistItem * )>(_a, &Playlist::signalAboutToRemove, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Playlist::*)(bool )>(_a, &Playlist::signalEnableDirWatch, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Playlist::*)(Playlist * )>(_a, &Playlist::signalPlaylistItemsDropped, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Playlist::*)()>(_a, &Playlist::signalMoveFocusAway, 4))
            return;
    }
}

const QMetaObject *Playlist::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Playlist::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8PlaylistE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PlaylistInterface"))
        return static_cast< PlaylistInterface*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int Playlist::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void Playlist::signalNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Playlist::signalAboutToRemove(PlaylistItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Playlist::signalEnableDirWatch(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Playlist::signalPlaylistItemsDropped(Playlist * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Playlist::signalMoveFocusAway()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
