/****************************************************************************
** Meta object code from reading C++ file 'tageditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../juk-26.04.1/tageditor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tageditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9TagEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto TagEditor::qt_create_metaobjectdata<qt_meta_tag_ZN9TagEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TagEditor",
        "slotSave",
        "",
        "slotSetItems",
        "PlaylistItemList",
        "list",
        "slotRefresh",
        "slotClear",
        "slotPlaylistDestroyed",
        "Playlist*",
        "p",
        "slotUpdateCollection",
        "slotDataChanged",
        "slotItemRemoved",
        "PlaylistItem*",
        "item",
        "slotPlaylistRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotSave'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetItems'
        QtMocHelpers::SlotData<void(const PlaylistItemList &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'slotRefresh'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClear'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPlaylistDestroyed'
        QtMocHelpers::SlotData<void(Playlist *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotUpdateCollection'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDataChanged'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotItemRemoved'
        QtMocHelpers::SlotData<void(PlaylistItem *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotPlaylistRemoved'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TagEditor, qt_meta_tag_ZN9TagEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TagEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TagEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TagEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9TagEditorE_t>.metaTypes,
    nullptr
} };

void TagEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TagEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotSave(); break;
        case 1: _t->slotSetItems((*reinterpret_cast<std::add_pointer_t<PlaylistItemList>>(_a[1]))); break;
        case 2: _t->slotRefresh(); break;
        case 3: _t->slotClear(); break;
        case 4: _t->slotPlaylistDestroyed((*reinterpret_cast<std::add_pointer_t<Playlist*>>(_a[1]))); break;
        case 5: _t->slotUpdateCollection(); break;
        case 6: _t->slotDataChanged(); break;
        case 7: _t->slotItemRemoved((*reinterpret_cast<std::add_pointer_t<PlaylistItem*>>(_a[1]))); break;
        case 8: _t->slotPlaylistRemoved(); break;
        default: ;
        }
    }
}

const QMetaObject *TagEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TagEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TagEditorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::TagEditor"))
        return static_cast< Ui::TagEditor*>(this);
    return QWidget::qt_metacast(_clname);
}

int TagEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
