/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.juk.player.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef PLAYERADAPTOR_H
#define PLAYERADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "playermanager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.juk.player
 */
class PlayerAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.juk.player")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.juk.player\">\n"
"    <method name=\"playing\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"paused\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"volume\">\n"
"      <arg direction=\"out\" type=\"d\"/>\n"
"    </method>\n"
"    <method name=\"status\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"trackProperties\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"trackProperty\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"property\"/>\n"
"    </method>\n"
"    <method name=\"play\"/>\n"
"    <method name=\"play\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"file\"/>\n"
"    </method>\n"
"    <method name=\"pause\"/>\n"
"    <method name=\"stop\"/>\n"
"    <method name=\"playPause\"/>\n"
"    <method name=\"back\"/>\n"
"    <method name=\"forward\"/>\n"
"    <method name=\"seekBack\"/>\n"
"    <method name=\"seekForward\"/>\n"
"    <method name=\"volumeUp\"/>\n"
"    <method name=\"volumeDown\"/>\n"
"    <method name=\"mute\"/>\n"
"    <method name=\"setVolume\">\n"
"      <arg direction=\"in\" type=\"d\" name=\"volume\"/>\n"
"    </method>\n"
"    <method name=\"playingString\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"currentTime\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"totalTime\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"currentTimeMSecs\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"totalTimeMSecs\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"randomPlayMode\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"setRandomPlayMode\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"randomMode\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    PlayerAdaptor(PlayerManager *parent);
    ~PlayerAdaptor() override;

    inline PlayerManager *parent() const
    { return static_cast<PlayerManager *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void back();
    int currentTime();
    int currentTimeMSecs();
    void forward();
    void mute();
    void pause();
    bool paused();
    void play(const QString &file);
    void play();
    void playPause();
    bool playing();
    QString playingString();
    QString randomPlayMode();
    void seekBack();
    void seekForward();
    void setRandomPlayMode(const QString &randomMode);
    void setVolume(double volume);
    int status();
    void stop();
    int totalTime();
    int totalTimeMSecs();
    QStringList trackProperties();
    QString trackProperty(const QString &property);
    double volume();
    void volumeDown();
    void volumeUp();
Q_SIGNALS: // SIGNALS
};

#endif
