/****************************************************************************
** Meta object code from reading C++ file 'collectionlist.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../juk-26.04.1/collectionlist.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'collectionlist.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14CollectionListE_t {};
} // unnamed namespace

template <> constexpr inline auto CollectionList::qt_create_metaobjectdata<qt_meta_tag_ZN14CollectionListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CollectionList",
        "signalCollectionChanged",
        "",
        "signalNewTag",
        "signalRemovedTag",
        "cachedItemsLoaded",
        "clear",
        "slotCheckCache",
        "slotRemoveItem",
        "file",
        "slotRefreshItem",
        "slotNewItems",
        "KFileItemList",
        "items",
        "slotRefreshItems",
        "QList<std::pair<KFileItem,KFileItem>>",
        "slotDeleteItems",
        "startLoadingCachedItems",
        "loadNextBatchCachedItems",
        "completedLoadingCachedItems"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalCollectionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalNewTag'
        QtMocHelpers::SignalData<void(const QString &, unsigned )>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::UInt, 2 },
        }}),
        // Signal 'signalRemovedTag'
        QtMocHelpers::SignalData<void(const QString &, unsigned )>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::UInt, 2 },
        }}),
        // Signal 'cachedItemsLoaded'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCheckCache'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveItem'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'slotRefreshItem'
        QtMocHelpers::SlotData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'slotNewItems'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'slotRefreshItems'
        QtMocHelpers::SlotData<void(const QList<QPair<KFileItem,KFileItem> > &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 13 },
        }}),
        // Slot 'slotDeleteItems'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'startLoadingCachedItems'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadNextBatchCachedItems'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'completedLoadingCachedItems'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CollectionList, qt_meta_tag_ZN14CollectionListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CollectionList::staticMetaObject = { {
    QMetaObject::SuperData::link<Playlist::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CollectionListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CollectionListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14CollectionListE_t>.metaTypes,
    nullptr
} };

void CollectionList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CollectionList *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalCollectionChanged(); break;
        case 1: _t->signalNewTag((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 2: _t->signalRemovedTag((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 3: _t->cachedItemsLoaded(); break;
        case 4: _t->clear(); break;
        case 5: _t->slotCheckCache(); break;
        case 6: _t->slotRemoveItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->slotRefreshItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->slotNewItems((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 9: _t->slotRefreshItems((*reinterpret_cast<std::add_pointer_t<QList<std::pair<KFileItem,KFileItem>>>>(_a[1]))); break;
        case 10: _t->slotDeleteItems((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 11: _t->startLoadingCachedItems(); break;
        case 12: _t->loadNextBatchCachedItems(); break;
        case 13: _t->completedLoadingCachedItems(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CollectionList::*)()>(_a, &CollectionList::signalCollectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionList::*)(const QString & , unsigned  )>(_a, &CollectionList::signalNewTag, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionList::*)(const QString & , unsigned  )>(_a, &CollectionList::signalRemovedTag, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionList::*)()>(_a, &CollectionList::cachedItemsLoaded, 3))
            return;
    }
}

const QMetaObject *CollectionList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CollectionList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CollectionListE_t>.strings))
        return static_cast<void*>(this);
    return Playlist::qt_metacast(_clname);
}

int CollectionList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Playlist::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void CollectionList::signalCollectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CollectionList::signalNewTag(const QString & _t1, unsigned  _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void CollectionList::signalRemovedTag(const QString & _t1, unsigned  _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void CollectionList::cachedItemsLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
